@@ -35,10 +35,20 @@ QUrl AppStreamUtils::imageOfKind(const QList<AppStream::Image> &images, AppStrea
 
 QString AppStreamUtils::changelogToHtml(const AppStream::Component &appdata)
 {
-    if (appdata.releases().isEmpty())
+#if ASQ_CHECK_VERSION(1, 0, 0)
+    const auto releases = appdata.releasesPlain();
+#else
+    const auto releases = appdata.releases();
+#endif
+    if (releases.isEmpty()) {
         return {};
+    }
 
-    const auto release = appdata.releases().constFirst();
+#if ASQ_CHECK_VERSION(1, 0, 0)
+    const auto release = releases.indexSafe(0).value();
+#else
+    const auto release = releases.constFirst();
+#endif
     if (release.description().isEmpty())
         return {};
 
@@ -47,21 +57,23 @@ QString AppStreamUtils::changelogToHtml(const AppStream::Component &appdata)
     return changelog;
 }
 
-QPair<QList<QUrl>, QList<QUrl>> AppStreamUtils::fetchScreenshots(const AppStream::Component &appdata)
+Screenshots AppStreamUtils::fetchScreenshots(const AppStream::Component &appdata)
 {
-    QList<QUrl> screenshots, thumbnails;
-    const auto appdataScreenshots = appdata.screenshots();
+    const auto appdataScreenshots = appdata.screenshotsAll();
+    Screenshots ret;
+    ret.reserve(appdataScreenshots.size());
     for (const AppStream::Screenshot &s : appdataScreenshots) {
         const auto images = s.images();
         const QUrl thumbnail = AppStreamUtils::imageOfKind(images, AppStream::Image::KindThumbnail);
-        const QUrl plain = AppStreamUtils::imageOfKind(images, AppStream::Image::KindSource);
-        if (plain.isEmpty())
-            qWarning() << "invalid screenshot for" << appdata.name();
+        const QUrl full = AppStreamUtils::imageOfKind(images, AppStream::Image::KindSource);
+        if (full.isEmpty()) {
+            qWarning() << "AppStreamUtils: Invalid screenshot for" << appdata.name();
+        }
+        const bool isAnimated = s.mediaKind() == AppStream::Screenshot::MediaKindVideo;
 
-        screenshots << plain;
-        thumbnails << (thumbnail.isEmpty() ? plain : thumbnail);
+        ret.append(Screenshot{thumbnail.isEmpty() ? full : thumbnail, full, isAnimated});
     }
-    return {thumbnails, screenshots};
+    return ret;
 }
 
 QJsonArray AppStreamUtils::licenses(const AppStream::Component &appdata)
@@ -71,7 +83,7 @@ QJsonArray AppStreamUtils::licenses(const AppStream::Component &appdata)
 
 QJsonArray AppStreamUtils::licenses(const QString &spdx)
 {
-    static const QSet<QChar> tokens = {'&', '+', '|', '^', '(', ')'};
+    static const QSet<QChar> tokens = {QLatin1Char('&'), QLatin1Char('+'), QLatin1Char('|'), QLatin1Char('^'), QLatin1Char('('), QLatin1Char(')')};
 
     QJsonArray ret;
     const auto licenses = AppStream::SPDX::tokenizeLicense(spdx);
@@ -121,27 +133,20 @@ QStringList AppStreamUtils::appstreamIds(const QUrl &appstreamUrl)
         ret << query.queryItemValue(QStringLiteral("alt")).split(QLatin1Char(','), Qt::SkipEmptyParts);
     }
     if (ret.removeDuplicates() != 0) {
-        qDebug() << "received malformed url" << appstreamUrl;
+        qDebug() << "AppStreamUtils: Received malformed url" << appstreamUrl;
     }
     return ret;
 }
 
 QString AppStreamUtils::versionString(const QString &version, const AppStream::Component &appdata)
 {
+    Q_UNUSED(appdata);
+
     if (version.isEmpty()) {
         return {};
-    } else {
-        if (appdata.releases().isEmpty())
-            return version;
-
-        auto release = appdata.releases().constFirst();
-        if (release.timestamp().isValid() && version.startsWith(release.version())) {
-            QLocale l;
-            return i18n("%1, released on %2", version, l.toString(release.timestamp().date(), QLocale::ShortFormat));
-        } else {
-            return version;
-        }
     }
+
+    return version;
 }
 
 QString AppStreamUtils::contentRatingDescription(const AppStream::Component &appdata)
@@ -238,7 +243,7 @@ uint AppStreamUtils::contentRatingMinimumAge(const AppStream::Component &appdata
 #endif
 }
 
-static void kRemoveDuplicates(QList<AppStream::Component> &input, AppStream::Bundle::Kind kind)
+static void kRemoveDuplicates(AppStream::ComponentBox &input, AppStream::Bundle::Kind kind)
 {
     QSet<QString> ret;
     for (auto it = input.begin(); it != input.end();) {
@@ -252,9 +257,9 @@ static void kRemoveDuplicates(QList<AppStream::Component> &input, AppStream::Bun
     }
 }
 
-QList<AppStream::Component> AppStreamUtils::componentsByCategories(AppStream::Pool *pool, Category *cat, AppStream::Bundle::Kind kind)
+AppStream::ComponentBox AppStreamUtils::componentsByCategories(AppStream::Pool *pool, Category *cat, AppStream::Bundle::Kind kind)
 {
-    QList<AppStream::Component> ret;
+    AppStream::ComponentBox ret(AppStream::ComponentBox::FlagNoChecks);
     for (const auto &categoryName : cat->involvedCategories()) {
         ret += pool->componentsByCategories({categoryName});
     }
