@@ -88,6 +88,17 @@ static T kFilter(const Q &input, _UnaryOperation op)
     return ret;
 }
 
+template<typename T, typename Q, typename _UnaryOperation>
+static void kFilterInPlace(Q &input, _UnaryOperation op)
+{
+    for (auto it = input.begin(); it != input.end();) {
+        if (op(*it))
+            ++it;
+        else
+            it = input.erase(it);
+    }
+}
+
 template<typename Q, typename W>
 static int kIndexOf(const Q &list, W func)
 {
@@ -121,13 +132,15 @@ static QVector<T> kSetToVector(const QSet<T> &set)
         ret.append(x);
     return ret;
 }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 template<typename T>
-static QSet<T> kToSet(const QVector<T> &set)
+static QList<T> kSetToList(const QSet<T> &set)
 {
-    return QSet<T>(set.begin(), set.end());
+    QList<T> ret;
+    ret.reserve(set.size());
+    for (auto &x : set)
+        ret.append(x);
+    return ret;
 }
-#endif
 template<typename T>
 static QSet<T> kToSet(const QList<T> &set)
 {
@@ -160,3 +173,26 @@ inline void swap(QJsonValueRef v1, QJsonValueRef v2)
     v1 = QJsonValue(v2);
     v2 = temp;
 }
+
+template<typename T>
+class KeyValueRange
+{
+public:
+    KeyValueRange(T &data)
+        : m_data{data}
+    {
+    }
+
+    auto begin()
+    {
+        return m_data.keyValueBegin();
+    }
+
+    auto end()
+    {
+        return m_data.keyValueEnd();
+    }
+
+private:
+    T &m_data;
+};
