@@ -40,8 +40,8 @@ DiscoverNotifier::DiscoverNotifier(QObject *parent)
 {
     m_settings = new UpdatesSettings(this);
     m_settingsWatcher = KConfigWatcher::create(m_settings->sharedConfig());
+    QNetworkInformation::loadBackendByFeatures(QNetworkInformation::Feature::Reachability | QNetworkInformation::Feature::TransportMedium);
     if (auto info = QNetworkInformation::instance()) {
-        info->loadBackendByFeatures(QNetworkInformation::Feature::Reachability | QNetworkInformation::Feature::TransportMedium);
         connect(info, &QNetworkInformation::reachabilityChanged, this, &DiscoverNotifier::stateChanged);
         connect(info, &QNetworkInformation::transportMediumChanged, this, &DiscoverNotifier::stateChanged);
     } else {
@@ -50,8 +50,12 @@ DiscoverNotifier::DiscoverNotifier(QObject *parent)
 
     refreshUnattended();
     connect(m_settingsWatcher.data(), &KConfigWatcher::configChanged, this, [this](const KConfigGroup &group, const QByteArrayList &names) {
-        if (group.config()->name() == m_settings->config()->name() && group.name() == QLatin1String("Global") && names.contains("UseUnattendedUpdates")) {
+        if (group.config()->name() != m_settings->config()->name() || group.name() != QLatin1String("Global")) {
+            return;
+        }
+        if (names.contains("UseUnattendedUpdates") || names.contains("RequiredNotificationInterval")) {
             refreshUnattended();
+            Q_EMIT stateChanged();
         }
     });
 
